@@ -2,6 +2,7 @@ package main
 
 import (
 	"fmt"
+	"net"
 	"net/url"
 	"os"
 	"strings"
@@ -9,6 +10,7 @@ import (
 
 	"github.com/go-git/go-git/v5"
 	"github.com/muesli/gitty/vcs"
+	"github.com/muesli/gitty/vcs/gitea"
 	"github.com/muesli/gitty/vcs/github"
 	"github.com/muesli/gitty/vcs/gitlab"
 )
@@ -70,14 +72,24 @@ func guessClient(host string) (Client, error) {
 	if strings.EqualFold(host, "gitlab.com") {
 		return gitlab.NewClient(host, token, true)
 	}
+	if strings.EqualFold(host, "gitea.com") {
+		return gitea.NewClient(host, token, true)
+	}
 	if strings.Contains(host, "invent.kde.org") {
 		return gitlab.NewClient(host, token, true)
 	}
 
-	client, err := gitlab.NewClient(host, token, false)
+	var client Client
+	var err error
+	client, err = gitlab.NewClient(host, token, false)
 	if err == nil {
 		return client, nil
 	}
+	client, err = gitea.NewClient(host, token, false)
+	if err == nil {
+		return client, nil
+	}
+	// fmt.Println(err)
 
 	return nil, fmt.Errorf("not a recognized git provider")
 }
@@ -112,11 +124,22 @@ func originURL(path string) (string, error) {
 
 func cleanupURL(arg string) (string, error) {
 	if strings.Contains(arg, "://") {
-		arg = strings.Split(arg, "://")[1]
-	}
-	arg = strings.ReplaceAll(arg, ":", "/")
-	arg = "https://" + arg
+		u, err := url.Parse(arg)
+		if err == nil {
+			host, _, err := net.SplitHostPort(u.Host)
+			if err == nil {
+				// strip port
+				u.Host = host
+				arg = u.String()
+			}
+		}
 
+		arg = strings.Split(arg, "://")[1]
+	} else {
+		arg = strings.ReplaceAll(arg, ":", "/")
+	}
+
+	arg = "https://" + arg
 	u, err := url.Parse(arg)
 	if err != nil {
 		return "", err
